import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_cloudwatch._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_kinesis._jsii
import aws_cdk.aws_kinesisfirehose._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_logs._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.core._jsii
import aws_solutions_constructs.aws_kinesis_firehose_s3._jsii
import aws_solutions_constructs.aws_kinesis_streams_lambda._jsii
import aws_solutions_constructs.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-solutions-constructs/aws-kinesisstreams-kinesisfirehose-s3",
    "1.116.0",
    __name__[0:-6],
    "aws-kinesisstreams-kinesisfirehose-s3@1.116.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
